@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.98 2008/01/16 20:42:44 raeburn Exp $
+# $Id: lonlogin.pm,v 1.100 2008/01/24 15:06:21 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -78,15 +78,14 @@ sub handler {
 	    &Apache::loncommon::start_page('Already logged in');
 	my $end_page = 
 	    &Apache::loncommon::end_page();
-	$r->print(<<ENDFAILED);
-$start_page
-<h1>You are already logged in</h1>
-<p>Please either <a href="/adm/roles">continue the current session</a> or
-<a href="/adm/logout">logout</a>.</p>
-<p>
-<a href="/adm/loginproblems.html">Problems?</a></p>
-$end_page
-ENDFAILED
+	$r->print(
+                  $start_page
+                 .'<h1>'.&mt('You are already logged in').'</h1>'
+                 .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]logout[_4].',
+                  '<a href="/adm/roles">','</a>','<a href="/adm/logout">','</a>').'</p>'
+                 .'<p><a href="/adm/loginproblems.html">'.&mt('Login problems?').'</a></p>'
+                 .$end_page
+                 );
         return OK;
     }
 
@@ -349,7 +348,14 @@ my %lt=&Apache::lonlocal::texthash(
 		  'serv' => 'Server',
                   'servadm' => 'Server Administration',
                   'helpdesk' => 'Contact Helpdesk',
-                  'forgotpw' => 'Forgot password?');
+                  'forgotpw' => 'Forgot password?',
+                  'options_headline' => 'Select Accessibility Options',
+                  'sprs_img' => 'Suppress rendering of images',
+                  'sprs_applet' => 'Suppress Java applets',
+                  'sprs_embed' => 'Suppress rendering of embedded multimedia',
+                  'sprs_font' => 'Increase font size',
+                  'sprs_blackwhite' => 'Switch to black and white mode',
+                  'remember' => 'Remember these settings for next login');
 # -------------------------------------------------- Change password field name
     my $forgotpw = &forgotpwdisplay(%lt);
     my $loginhelp = &loginhelpdisplay(%lt);
@@ -454,18 +460,21 @@ ENDSERVERFORM
    <td align="center" valign="middle" bgcolor="$sidebg">
 ENDTOP
 } else {
-    $r->print('<h1>The Learning<i>Online</i> Network with CAPA</h1><h2>Text-based Interface Login</h2>'.$announcements);
+    $r->print('<h1>The Learning<i>Online</i> Network with CAPA</h1>'
+             .'<h2>'.&mt('Text-based Interface Login').'</h2>'
+             .$announcements);
 }
     $r->print('<form name="client" onsubmit="return(send())">');
     unless ($fullgraph) {
         $r->print(<<ENDACCESSOPTIONS);
-<h3>Select Accessibility Options</h3>
-<label><input type="checkbox" name="imagesuppress" /> Suppress rendering of images</label><br />
-<label><input type="checkbox" name="appletsuppress" /> Suppress Java applets</label><br />
-<label><input type="checkbox" name="embedsuppress" /> Suppress rendering of embedded multimedia</label><br />
-<label><input type="checkbox" name="fontenhance" /> Increase font size</label><br />
-<label><input type="checkbox" name="blackwhite" /> Switch to black and white mode</label><br />
-<input type="checkbox" name="remember" /> Remember these settings for next login<hr />
+<h3>$lt{'options_headline'}</h3>
+<label><input type="checkbox" name="imagesuppress" /> $lt{'sprs_img'}</label><br />
+<label><input type="checkbox" name="appletsuppress" /> $lt{'sprs_applet'}</label><br />
+<label><input type="checkbox" name="embedsuppress" /> $lt{'sprs_embed'}</label><br />
+<label><input type="checkbox" name="fontenhance" /> $lt{'sprs_font'}</label><br />
+<label><input type="checkbox" name="blackwhite" /> $lt{'sprs_blackwhite'}</label><br />
+<br />
+<input type="checkbox" name="remember" /> $lt{'remember'}<hr />
 ENDACCESSOPTIONS
 } else {
     $r->print(<<ENDNOOPT);
