@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.29 2007/10/02 01:09:59 albertel Exp $
+# $Id: lonlogout.pm,v 1.30 2008/04/02 12:29:38 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -87,15 +87,8 @@ sub handler {
     } else {
 	$start_page=&Apache::loncommon::start_page('Logged Out',undef,
 						   {'no_inline_link' => 1,});
-	my %lt=&Apache::lonlocal::texthash('gb' => 'Goodbye',
-					   'cw' => 'close this window',
-					   'li' => 'log in again',
-					   'pe' => 'Please either',
-					   'or' => 'or');
 	
-	$relogmessage.=(<<ENDRELOG);
-	<h1>$lt{'gb'}!</h1>
-ENDRELOG
+	$relogmessage.='<h1>'.&mt('Goodbye').'</h1>';
 
 	if (!$env{'request.sso.norelogin'}) {
 	    my $relogin_server;
@@ -105,11 +98,9 @@ ENDRELOG
 	    my $login_url = $relogin_server.'/adm/'.
 		($env{'request.sso.login'} ? 'roles': 'login');
 
-	    $relogmessage.=(<<ENDRELOG);
-	    $lt{'pe'} <a href="javascript:self.close();">$lt{'cw'}</a> $lt{'or'}
-	<a href="$login_url?domain=$env{'user.domain'}">$lt{'li'}</a>.
-ENDRELOG
-
+	    $relogmessage.=&mt('Please either [_1]close this window[_2] or [_3]log in again[_4].'
+                              ,'<a href="javascript:self.close();">','</a>'
+                              ,'<a href="'.$login_url.'?domain='.$env{'user.domain'}.'">','</a>');
         }
 	my $domain = $env{'user.domain'};
         if ($env{'request.sso.login'}
