@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.181 2007/11/09 20:56:34 albertel Exp $
+# $Id: lonroles.pm,v 1.181.2.2 2008/03/22 03:52:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -365,7 +365,7 @@ ENDENTERKEY
     my $start_page=&Apache::loncommon::start_page('User Roles');
     my $standby=&mt('Role selected. Please stand by.');
     $standby=~s/\n/\\n/g;
-    my $noscript='<span class="LC_error">'.&mt('Use of LON-CAPA requires Javascript to be enabled in your web browser.').'<br />'.&mt('As this is not the case, most functionality in the system will ba unavailable.').'</span><br />';
+    my $noscript='<span class="LC_error">'.&mt('Use of LON-CAPA requires Javascript to be enabled in your web browser.').'<br />'.&mt('As this is not the case, most functionality in the system will be unavailable.').'</span><br />';
 
     $r->print(<<ENDHEADER);
 $start_page
@@ -410,16 +410,16 @@ ENDHEADER
 # -------------------------------------------------------- Generate Page Output
 # --------------------------------------------------------------- Error Header?
     if ($error) {
-	$r->print("<h1>LON-CAPA Access Control</h1>");
+        $r->print("<h1>".&mt('LON-CAPA Access Control')."</h1>");
 	$r->print("<!-- LONCAPAACCESSCONTROLERRORSCREEN --><hr /><pre>");
 	if ($priv ne '') {
-	    $r->print("Access  : ".&Apache::lonnet::plaintext($priv)."\n");
+            $r->print(&mt('Access  : ').&Apache::lonnet::plaintext($priv)."\n");
 	}
 	if ($fn ne '') {
-	    $r->print("Resource: ".&Apache::lonenc::check_encrypt($fn)."\n");
+            $r->print(&mt('Resource: ').&Apache::lonenc::check_encrypt($fn)."\n");
 	}
 	if ($msg ne '') {
-	    $r->print("Action  : $msg\n");
+            $r->print(&mt('Action  : ').$msg."\n");
 	}
 	$r->print("</pre><hr />");
 	my $url=$fn;
@@ -930,6 +930,10 @@ sub courselink {
 }
 
 sub coursepick_jscript {
+    my %lt = &Apache::lonlocal::texthash(
+                  plsu => "Please use the 'Select Course' link to open a separate pick course window where you may select the course you wish to enter.",
+                  youc => 'You can only use this screen to select courses in the current domain.',
+            );
     my $verify_script = <<"END";
 <script type="text/javascript">
 function verifyCoursePick(caller) {
@@ -945,11 +949,11 @@ function verifyCoursePick(caller) {
             }
         }
         else {
-            alert("Please use the 'Select Course' link to open a separate pick course window where you may select the course you wish to enter.");
+            alert("$lt{'plsu'}");
         }
     }
     else {
-        alert("You can only use this screen to select courses in the current domain")
+        alert("$lt{'youc'}");
     }
 }
 function getIndex(caller) {
