@@ -1,5 +1,5 @@
 #
-# $Id: batchcreatecourse.pm,v 1.24 2007/09/03 15:34:16 raeburn Exp $
+# $Id: batchcreatecourse.pm,v 1.25 2008/02/07 01:43:21 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -219,7 +219,7 @@ sub create_courses {
                 &parse_coursereqs($newcoursedir.'/'.$request, \%details);
                 foreach my $num (sort keys %details) {
                     my $courseid = &build_course($dom,$num,$context,\%details,\%longroles,\$logmsg,\$newusermsg,\$addresult,\%enrollcount,\$output,\$keysmsg);
-                    if ($courseid =~ /^$match_courseid$/) {
+                    if ($courseid =~m{^/$match_domain/$match_courseid}) {
                         $$courseids{$courseid} = $details{$num}{'class'};
                     }
                 }
