@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.75 2007/10/15 09:47:29 foxr Exp $
+# $Id: chemresponse.pm,v 1.77 2008/02/06 16:32:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -337,6 +337,7 @@ sub end_organicresponse {
 	&Apache::lonxml::increment_counter(&Apache::response::repetition(), 
 					   "$partid.$id"); # part.response
 	if ($target eq 'analyze') {
+            $Apache::lonhomework::analyze{"$partid.$id.type"} = 'organicresponse';
 	    &Apache::lonhomework::set_bubble_lines();
 	}
     }
@@ -565,6 +566,10 @@ sub end_reactionresponse {
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
 	&Apache::lonxml::increment_counter(&Apache::response::repetition(), "$partid.$id");
+        if ($target eq 'analyze') {
+            $Apache::lonhomework::analyze{"$partid.$id.type"} = 'reactionresponse';
+            &Apache::lonhomework::set_bubble_lines();
+        }
     }
     &Apache::response::end_response();
     return $result;
