@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.237 2008/01/28 21:42:28 www Exp $
+# $Id: inputtags.pm,v 1.242 2008/03/17 15:40:31 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -306,7 +306,9 @@ sub start_textline {
 		$oldresponse = $oldresponse->[$#Apache::inputtags::inputlist];
 	    }
 	    $oldresponse = &HTML::Entities::encode($oldresponse,'<>&"');
-
+            $oldresponse =~ s/^\s+//;
+            $oldresponse =~ s/\s+$//;
+            $oldresponse =~ s/\s+/ /g;
 	    if ($Apache::lonhomework::type ne 'exam') {
 		my $addchars=&Apache::lonxml::get_param('addchars',$parstack,$safeeval);
 		$result='';
@@ -743,10 +745,10 @@ sub decideoutput {
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'MISORDERED_RANK') {
-	$message = &mt('You have provided an invalid ranking');
-	if ($target ne 'tex') {
-	    $message.=', '.&mt('please refer to').' '.&Apache::loncommon::help_open_topic('Ranking_Problems','help on ranking problems');
-	}
+        $message = &mt('You have provided an invalid ranking.');
+        if ($target ne 'tex') {
+            $message.=' '.&mt('Please refer to [_1]',&Apache::loncommon::help_open_topic('Ranking_Problems',&mt('help on ranking problems')));
+        }
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'INVALID_FILETYPE') {
@@ -788,7 +790,8 @@ sub decideoutput {
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'BAD_FORMULA') {
-	$message = &mt("Unable to understand formula");
+	$message = &mt("Unable to understand formula").'.';
+        if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Formula_Answers')};
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'INCORRECT') {
@@ -1256,11 +1259,11 @@ sub previous_tries {
 		&& $Apache::lonhomework::history{"$prefix.solved"} =~/^correct/
 		) {
 		
+                my $txt_correct = &mt('Correct');
 		$message =~ s{(<td.*?>)(.*?)(</td>)}
-		             {$1 <strong>Correct</strong>. $3}s;
+                             {$1 <strong>$txt_correct</strong>. $3}s;
 	    }
-	    my $trystr = "(Try ".
-		$Apache::lonhomework::history{"$prefix.tries"}.')';
+            my $trystr = "(".&mt('Try [_1]',$Apache::lonhomework::history{"$prefix.tries"}).")";
 	    $message =~ s{(</td>)}{ $trystr $1};
 	}
 	my ($class) = ($message =~ m{<td.*class="([^"]*)"}); #"
