@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.287 2007/12/24 06:35:18 raeburn Exp $
+# $Id: lonhomework.pm,v 1.289 2008/01/15 03:09:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -137,8 +137,8 @@ sub get_target {
 	    if ($env{'form.problemstate'} eq 'WEB_GRADE') {
 		#$env{'form.webgrade'} = 'yes';
 		return ('grade','webgrade','answer');
-	    } elsif ( $env{'form.problemmode'} eq &mt('View') ||
-		 $env{'form.problemmode'} eq &mt('Discard Edits and View')) {
+	    } elsif (($env{'form.problemmode'} eq 'view') ||
+		     ($env{'form.problemmode'} eq 'discard')) {
 		if ( defined($env{'form.submitted'}) &&
 		     (!defined($env{'form.resetdata'})) &&
 		     (!defined($env{'form.newrandomization'}))) {
@@ -146,10 +146,9 @@ sub get_target {
 		} else {
 		    return ('web','answer');
 		}
-	    } elsif ( $env{'form.problemmode'} eq &mt('Edit') ||
-		      $env{'form.problemmode'} eq 'Edit') {
+	    } elsif ($env{'form.problemmode'} eq 'edit') {
 		if ( $env{'form.submitted'} eq 'edit' ) {
-		    if ( $env{'form.submit'} eq &mt('Save and View') ) {
+		    if ( $env{'form.submitbutton'} eq &mt('Save and View') ) {
 			return ('modified','web','answer');
 		    } else {
 			return ('modified','no_output_web','edit');
@@ -292,9 +291,9 @@ sub check_slot_access {
 	}
     }
 
-    my @slots=
-	(split(':',&Apache::lonnet::EXT("resource.0.availablestudent")),
-	 split(':',&Apache::lonnet::EXT("resource.0.available")));
+    my $availablestudent = &Apache::lonnet::EXT("resource.0.availablestudent");
+    my $available = &Apache::lonnet::EXT("resource.0.available");
+    my @slots= (split(':',$availablestudent),split(':',$available));
 
 #    if (!@slots) {
 #	return ($status,$datemsg);
@@ -421,7 +420,8 @@ sub check_access {
     &Apache::lonxml::debug("symb:".$symb);
     #if ($env{'request.state'} ne "construct" && $symb ne '') {
     if ($env{'request.state'} ne "construct") {
-	my $allowed=&check_ip_acc(&Apache::lonnet::EXT("resource.$id.acc"));
+        my $idacc = &Apache::lonnet::EXT("resource.$id.acc");
+	my $allowed=&check_ip_acc($idacc);
 	if (!$allowed && ($Apache::lonhomework::browse ne 'F')) {
 	    $status='INVALID_ACCESS';
 	    $date=&mt("can not be accessed from your location.");
@@ -743,20 +743,25 @@ sub handle_save_or_undo {
 
 sub analyze_header {
     my ($request) = @_;
+    my $js = &Apache::structuretags::setmode_javascript();
     my $result =
-	&Apache::loncommon::start_page('Analyzing a problem',undef);
+	&Apache::loncommon::start_page('Analyzing a problem',$js);
 
     $result .= 
 	&Apache::lonxml::message_location().'
             <form name="lonhomework" method="POST" action="'.
 	    &HTML::Entities::encode($env{'request.uri'},'<>&"').'">'.
+            '<input type="hidden" name="problemmode" value="'.
+            $env{'form.problemmode'}.'" />'.
 	    &Apache::structuretags::remember_problem_state().'
             <div class="LC_edit_problem_analyze_header">
-            <input type="submit" name="problemmode" value="'.&mt("EditXML").'" />
-            <input type="submit" name="problemmode" value="'.&mt('Edit').'" />
+            <input type="button" name="submitmode" value="'.&mt("EditXML").'" '.
+            'onclick="javascript:setmode(this.form,'."'editxml'".')" />
+            <input type="button" name="submitmode" value="'.&mt('Edit').'" '.
+            'onclick="javascript:setmode(this.form,'."'edit'".')" />
             <hr class="LC_edit_problem_divide" />
-
-            <input type="submit" name="submit" value="'.&mt("View").'" />
+            <input type="button" name="submitmode" value="'.&mt("View").'" '.
+            'onclick="javascript:setmode(this.form,'."'view'".')" />
             <hr class="LC_edit_problem_divide" />
             </div>
             </form>';
@@ -919,9 +924,9 @@ sub editxmlmode {
 	if (!$error) { $problem=&Apache::lonnet::getfile($file); }
     }
     &Apache::lonhomework::showhashsubset(\%env,'^form');
-    if ( $env{'form.submit'} eq &mt('Save and View') ) {
+    if ( $env{'form.submitbutton'} eq &mt('Save and View') ) {
 	&Apache::lonhomework::showhashsubset(\%env,'^form');
-	$env{'form.problemmode'}='View';
+	$env{'form.problemmode'}='view';
 	&renderpage($request,$file);
     } else {
 	my ($rows,$cols) = &Apache::edit::textarea_sizes(\$problem);
@@ -936,7 +941,8 @@ sub editxmlmode {
 	if ($rows < 20) { $rows = 20; }
 	my $js =
 	    &Apache::edit::js_change_detection(). 
-	    &Apache::loncommon::resize_textarea_js();
+	    &Apache::loncommon::resize_textarea_js().
+            &Apache::structuretags::setmode_javascript();
 	my $only_body =  ($env{'environment.remote'} eq 'off')? 0 : 1;
 	my $start_page = 
 	    &Apache::loncommon::start_page(&mt("EditXML [_1]",$file),$js,
@@ -946,7 +952,6 @@ sub editxmlmode {
 						'onresize' => q[resize_textarea('LC_editxmltext','LC_aftertextarea')],
 						'onload'   => q[resize_textarea('LC_editxmltext','LC_aftertextarea')],
 				    }});
-
 	$result.=$start_page.
 	    &renderpage($request,$file,['no_output_web'],1).
             '<form '.&Apache::edit::form_change_detection().' name="lonhomework" method="POST" action="'.
@@ -960,14 +965,15 @@ sub editxmlmode {
                 </td></tr>
               </table>
               <div class="LC_edit_problem_discards">
-                <input type="hidden" name="problemmode" value="'.&mt('EditXML').'" />
-                <input type="submit" name="problemmode" accesskey="d" value="'.&mt('Discard Edits and View').'" />
-                <input type="submit" '.&Apache::edit::submit_ask_anyway().'name="problemmode" accesskey="e" value="'.&mt('Edit').'" />
+                <input type="hidden" name="problemmode" value="editxml" />
+                <input type="button" name="submitmode" accesskey="d" value="'.&mt('Discard Edits and View').'" '.
+                'onclick="javascript:setmode(this.form,'."'discard'".')" />
+                <input type="button" '.&Apache::edit::submit_ask_anyway('setmode(this.form,'."'edit'".')').'name="submitmode" accesskey="e" value="'.&mt('Edit').'" />
                 <input type="submit" name="Undo" accesskey="u" value="'.&mt('undo').'" />
               </div>
               <div class="LC_edit_problem_saves">
-                <input type="submit" name="submit" accesskey="s" value="'.&mt('Save').'" />
-                <input type="submit" name="submit" accesskey="v" value="'.&mt('Save and View').'" />
+                <input type="submit" name="submitbutton" accesskey="s" value="'.&mt('Save').'"  />
+                <input type="submit" name="submitbutton" accesskey="v" value="'.&mt('Save and View').'" />
               </div>
               <hr class="LC_edit_problem_divide" />
 	      '.&Apache::lonxml::message_location().'
@@ -1168,7 +1174,7 @@ $errormsg
 
 sub update_construct_style {
     if ($env{'request.state'} eq "construct"
-	&& $env{'form.problemmode'} eq &mt('View') 
+	&& $env{'form.problemmode'} eq 'view' 
 	&&  defined($env{'form.submitted'})
 	&& !defined($env{'form.resetdata'})
 	&& !defined($env{'form.newrandomization'})) {
@@ -1191,13 +1197,6 @@ sub handler {
     $Apache::lonxml::debug=$env{'user.debug'};
     $env{'request.uri'}=$request->uri;
     &setuppermissions();
-    # some times multiple problemmodes are submitted, need to select
-    # the last one
-    if ( defined($env{'form.problemmode'}) && ref($env{'form.problemmode'}) ) {
-	my $mode=$env{'form.problemmode'}->[-1];
-	undef $env{'form.problemmode'};
-	$env{'form.problemmode'}=$mode;
-    }
 
     my $file=&Apache::lonnet::filelocation("",$request->uri);
 
@@ -1226,12 +1225,11 @@ sub handler {
 						    ['problemmode']);
 	    if (!(defined $env{'form.problemmode'})) {
 		#first visit to problem in construction space
-		$env{'form.problemmode'}='View';
+		$env{'form.problemmode'}= 'view';
 		&renderpage($request,$file);
-	    } elsif ($env{'form.problemmode'} eq &mt('EditXML') ||
-		     $env{'form.problemmode'} eq 'EditXML') {
+	    } elsif ($env{'form.problemmode'} eq 'editxml') {
 		&editxmlmode($request,$file);
-	    } elsif ($env{'form.problemmode'} eq &mt('Calculate answers')) {
+	    } elsif ($env{'form.problemmode'} eq 'calcanswers') {
 		&analyze($request,$file);
 	    } else {
 		&update_construct_style();
