@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.417 2008/01/28 21:42:28 www Exp $
+# $Id: structuretags.pm,v 1.419 2008/02/13 16:21:44 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -477,8 +477,8 @@ $show_all
 	$result .= '<span class="LC_nobreak">'.
 	    &mt('[_1] for [_2] versions.',
 		'<input type="button" name="submitmode" value="'.&mt('Calculate answers').'" '.
-                'onclick="javascript:setmode(this.form,'."'calcanswers'".')" />
-		<input type="text" name="numtoanalyze" value="'.
+                'onclick="javascript:setmode(this.form,'."'calcanswers'".')" />'
+               ,'<input type="text" name="numtoanalyze" value="'.
 		$numtoanalyze.'" size="5" />').
 		&Apache::loncommon::help_open_topic("Analyze_Problem",'',undef,undef,300).
 		'</span>';
@@ -645,26 +645,27 @@ sub firstaccess_msg {
 	my $foldertitle=&Apache::lonnet::gettitle($map);
     
 	&Apache::lonxml::debug("map is $map title is $foldertitle");
-	$result .= (<<ENDCHECKOUT);
-<h2>The resources in "$foldertitle" are open for a limited time. Once you click the 'Show Resource' button below you have $time to complete all resources "$foldertitle".</h2>
-ENDCHECKOUT
+	$result .= "<h2>".&mt('The resources in "[_1]" are open for a limited time.'
+                             .' Once you click the "Show Resource" button below you have [_2] to complete all resources "[_1]".'
+                             ,$foldertitle,$time)."</h2>";
     } elsif ($interval[1] eq 'course') {
 	my $course = $env{'course.'.$env{'request.course.id'}.'.description'};
-	$result .= (<<ENDCHECKOUT);
-<h2>The resources in "$course" are open for a limited time. Once you click the 'Show Resource' button below you have $time to complete all resources in "$course".</h2>
-ENDCHECKOUT
+        $result .= "<h2>".&mt('The resources in "[_1]" are open for a limited time.'
+                             .' Once you click the "Show Resource" button below you have [_2] to complete all resources "[_1]".'
+                             ,$course,$time)."</h2>";
     } else {
 	my $title=&Apache::lonnet::gettitle($symb);
-	$result .= (<<ENDCHECKOUT);
-<h2>This resource "$title" is open for a limited time. Once you click the 'Show Resource' button below you have $time to complete this resource "$title".</h2>
-ENDCHECKOUT
-
+        $result .= "<h2>".&mt('This resource "[_1]" is open for a limited time.'
+                             .' Once you click the "Show Resource" button below you have [_2] to complete this resource "[_1]".'
+                             ,$title,$time)."</h2>";
     }
     my $uri = &Apache::lonenc::check_encrypt($env{'request.uri'});
+    my $buttontext = &mt('Show Resource');
+    my $timertext = &mt('Start Timer?');
     $result .= (<<ENDCHECKOUT);
 <form name="markaccess" method="POST" action="$uri">
 <input type="hidden" name="markaccess" value="yes" />
-<input type="button" name="accessbutton" value="Show Resource" onClick="javascript:if (confirm('Start Timer?')) { document.markaccess.submit(); }" />
+<input type="button" name="accessbutton" value="$buttontext" onClick="javascript:if (confirm('$timertext')) { document.markaccess.submit(); }" />
 </form>
 ENDCHECKOUT
     return $result;
