@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.172 2008/01/15 03:42:35 raeburn Exp $
+# $Id: lonhtmlcommon.pm,v 1.173 2008/03/06 22:30:17 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1337,7 +1337,7 @@ returns: nothing
 # row1
 # row2
 # row3   ... etc.
-# &submit_row(0
+# &submit_row()
 # &end_pick_box()
 #
 # where row1, row 2 etc. are chosen from &role_select_row,&course_select_row,
@@ -1407,10 +1407,13 @@ sub row_title {
     $css_value_class ||= 'LC_pick_box_value';
     $css_value_class = 'class="'.$css_value_class.'"';
 
+    if ($title ne '') {
+        $title .= ':';
+    }
     my $output = <<"ENDONE";
            <tr class="LC_pick_box_row">
             <td $css_title_class>
-	       $title:
+	       $title
             </td>
             <td $css_value_class>
 ENDONE
