@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.67.2.2 2008/01/02 11:25:38 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.67.2.3 2008/01/20 22:47:37 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -474,11 +474,8 @@ $multelement
                   '<input type="text" name="descriptfilter" size="40" value="'.
                   $list->{'descriptfilter'}.'" />'."\n";
     }
-    $output .= qq|
-<p><input type="submit" name="gosearch" value="Search" /></p>
-</form>
-<hr />
-|;
+    $output .= '<p><input type="submit" name="gosearch" value="'. 
+               &mt('Search').'" /></p>'."\n".'</form>'."\n".'<hr />'."\n";
     return $output; 
 }
 
