@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a student from the classlist
 #
-# $Id: lonpickstudent.pm,v 1.23 2007/08/10 23:20:09 albertel Exp $
+# $Id: lonpickstudent.pm,v 1.24 2007/09/02 01:30:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -208,7 +208,7 @@ ENDSCRIPT
 		     /^($LONCAPA::username_re):($LONCAPA::domain_re):(\w+)$/);
 	    my ($uname,$udom,$urole)=($1,$2,$3);
 	    my $fullname=&Apache::loncommon::plainname($uname,$udom);
-	    next if (($uname!~/^$filter/i) && ($fullname=~/^$filter/i));
+	    next if (($uname!~/^$filter/i) && ($fullname !~/^$filter/i));
 	    
 	    if (!exists($users{"$uname:$udom"})) {
 		$users{"$uname:$udom"} = {'fullname' => $fullname };
