@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.113 2008/01/21 04:30:05 raeburn Exp $
+# $Id: lonpreferences.pm,v 1.115 2008/03/06 22:27:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -581,7 +581,7 @@ sub clickerchanger {
     $clickers=~s/\,/\n/gs;
     my $text=&mt('Enter response device ("clicker") numbers');
     my $change=&mt('Register');
-    my $helplink=&Apache::loncommon::help_open_topic('Clicker_Registration', 'Locating your clicker ID');
+    my $helplink=&Apache::loncommon::help_open_topic('Clicker_Registration',&mt('Locating your clicker ID'));
     $r->print(<<ENDSCREEN);
 <form name="prefs" action="/adm/preferences" method="post">
 <input type="hidden" name="action" value="verify_and_change_clicker" />
@@ -1165,7 +1165,7 @@ sub jscript_send {
 sub client_form {
     my ($caller,$hexkey,$currentpass,$defdom) = @_;
     my %lt=&Apache::lonlocal::texthash(
-                'email' => 'EMail Address',
+                'email' => 'E-mail Address',
                 'username' => 'Username',
                 'domain' => 'Domain',
                 'currentpass' => 'Current Password',
@@ -1186,7 +1186,7 @@ sub client_form {
      <input type="text" name="uname" size="15" />
      <input type="hidden" name="currentpass" value="$currentpass" />
     </td></tr>
-<tr><td class="LC_preferences_labeltext"><label for="udom">$lt{'udom'}</label>:</td>
+<tr><td class="LC_preferences_labeltext"><label for="udom">$lt{'domain'}</label>:</td>
     <td>
 |;
         $output .= &Apache::loncommon::select_dom_form($defdom,'udom').'
