@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.73 2007/09/26 12:34:19 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.76 2008/03/18 22:00:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -308,10 +308,18 @@ sub display_actions_box {
                   '</a></span><br />');
         }
     }
-    $r->print(&mt('Page set to be displayed after you have selected a role in this '.$lctype).
-              '. <span class="LC_nobreak">'.&mt('Currently: <i>[_1]</i>',$currinit).'.&nbsp;&nbsp;'.
-              &mt('<b>Change</b> for just <a href="/adm/whatsnew?command=courseinit&amp;refpage=[_1]">this '.$lctype.'</a>',$refpage).' '.
-              &mt('or for all <a href="/adm/preferences?action=changecourseinit&amp;refpage=[_1]">your courses</a>.',$refpage).'</span><br /><hr />');
+    $r->print(&mt('Page set to be displayed after you have selected a role in this '.$lctype).'.'
+              .' <span class="LC_nobreak">'
+              .&mt('Currently: <i>[_1]</i>',$currinit)
+              .'.&nbsp;&nbsp;'
+#              &mt('<b>Change</b> for just <a href="/adm/whatsnew?command=courseinit&amp;refpage=[_1]">this '.$lctype.'</a>',$refpage).' '.
+#              &mt('or for all <a href="/adm/preferences?action=changecourseinit&amp;refpage=[_1]">your courses</a>.',$refpage).'</span><br /><hr />');
+              .&mt('<b>Change</b> for just [_1]this course[_2]'
+                  .' or for all [_3]your courses[_2].'
+                  ,'<a href="/adm/whatsnew?command=courseinit&amp;refpage='.$refpage.'">'
+                  ,'</a>'
+                  ,'<a href="/adm/preferences?action=changecourseinit&amp;refpage='.$refpage.'">')
+              .' </span><br /><hr />');
 
     if ($command eq 'reset') {
         $result = &process_reset($cdom,$crs);
@@ -488,7 +496,7 @@ sub display_threshold_config {
                  &Apache::loncommon::end_data_table_row());
     }
     $r->print(&Apache::loncommon::end_data_table()."\n".
-          '<br /><input type="submit" name="threshold" value="Make changes" />
+          '<br /><input type="submit" name="threshold" value="'.&mt('Make changes').'" />
                  <input type="hidden" name="command" value="update" />
                  <input type="hidden" name="refpage" value="'.$refpage.'" />
                </form>');
@@ -506,10 +514,10 @@ sub display_interval_config {
     my $lctype = lc(&Apache::loncommon::course_type());
     my $current = &get_current($env{'user.name'},$env{'user.domain'},
                                 $env{'request.course.id'},'interval');
-    $r->print('<br />'.&mt('Choose the time window to use for display of version changes for resources in the '.$lctype.'.'));
+    $r->print('<br />'.&mt('Choose the time window to use for display of version changes for resources in the '.$lctype.'.').'<br />');
     unless ($current eq '') {
-        $r->print(' '.&mt('Current value is [_1]','<b>'.
-                  $$interval_titles{$current}.'</b>.'));
+        $r->print(' '.&mt('Current value is [_1].','<b>'.
+                  $$interval_titles{$current}.'</b>'));
     }
     $r->print('<br /><br />
 <form method="post" name="intervalswitch" action="/adm/whatsnew">
@@ -562,7 +570,7 @@ function toggle_countunread(choice) {
 ');
     $r->print('<br/>
                <input type="button" name="display" value="'.
-               &mt('Change to [_1]',$opposite{$current}).'" 
+               &mt('Change to [_1]',&mt($opposite{$current})).'" 
                onclick="javascript:toggle_countunread('."'change'".')" />
                &nbsp;&nbsp;&nbsp;&nbsp;&nbsp&nbsp;&nbsp;
                <input type="button" name="nochange" value="'.
@@ -866,10 +874,10 @@ sub check_thresholds {
                 my $resettitle = 'title_'.&escape($symb."\0".$part);
                 if (@parts > 1) {
                     $$triggered{$symb}{text}[$partcount] = '
-                     <td>part - '.$part.'</td>';
+                     <td>'.&mt('part - ').$part.'</td>';
                 } else {
                     $$triggered{$symb}{text}[$partcount] = '
-                     <td>single part</td>';
+                     <td>'.&mt('single part').'</td>';
                 }
                 $$triggered{$symb}{text}[$partcount] .= '
                      <td>'.$stats{$part}{users}.'</td>
@@ -979,7 +987,7 @@ sub process_reset {
 
 sub process_update {
     my ($uname,$udom,$threshold_titles) = @_;
-    my $setoutput = '<b>Changes to threshold(s) for problem tracking:</b><br />';
+    my $setoutput = '<b>'.&mt('Changes to threshold(s) for problem tracking:').'</b><br />';
     foreach (keys %env) {
         next if ($_!~/^form\.(.+)\_setparmval$/);
         my $name  = $1;
@@ -1326,11 +1334,12 @@ sub display_coursenormalmail {
         foreach my $msg (@{$newmsgs}) {
             $mailcount ++;
             my $css_class = $mailcount%2?' class="LC_odd_row"':'';
-            $r->print('<tr'.$css_class.'><td>'.$mailcount.
-                      '. &nbsp;</td><td><a href="/adm/communicate">'.
-                      $msg->{'shortsub'}.'</a>&nbsp; &nbsp;</td><td>&nbsp;'.
-                      $msg->{'from'}.':'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
-                      $msg->{'sendtime'}.'</td></tr>');
+            $r->print('<tr'.$css_class.'><td>'.$mailcount
+                      .'.&nbsp;</td><td><a href="/adm/email?display='
+                      .$msg->{'msgid'}.'">'
+                      .$msg->{'shortsub'}.'</a>&nbsp;&nbsp;</td><td>&nbsp;'
+                      .$msg->{'from'}.':'.$msg->{'fromdom'}.'&nbsp;</td><td>'
+                      .$msg->{'sendtime'}.'</td></tr>');
         }
     } else {
         $r->print('<tr class="LC_empty_row"><td>'.
@@ -1417,7 +1426,7 @@ sub store_interval_setting {
                                              \%interval_settings,$udom,$uname);
         if ($outcome eq 'ok') {
             $result = &mt('Interval set to version changes [_1]',
-                  '<b>'.$$interval_titles{$env{'form.interval'}}.'</b><br />');
+                  '<b>'.$$interval_titles{$env{'form.interval'}}.'</b>').'<br />';
 
         } else {
 	    my $lctype = lc(&Apache::loncommon::course_type());
@@ -1441,7 +1450,7 @@ sub store_discussion_setting {
                                              \%discussion_settings,$udom,$uname);
         if ($outcome eq 'ok') {
             $result = &mt('Count unread posts in discussions display set to [_1]',
-                  '<b>'.$env{'form.countunread'}.'</b><br />');
+                  '<b>'.&mt($env{'form.countunread'}).'</b>').'<br />';
                                                                                   
         } else {
 	    my $lctype = lc(&Apache::loncommon::course_type());
@@ -1449,7 +1458,7 @@ sub store_discussion_setting {
                 ' '.$outcome.' for '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
             $result = &mt('Unable to set "number unread posts display" to [_1]'.
                           ' due to [_2].',
-                         '<b>'.$env{'form.countunread'}.'</b>',
+                         '<b>'.&mt($env{'form.countunread'}).'</b>',
                          '<tt>'.$outcome.'</tt>.<br />');
         }
     }
