@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # portfolio browser
 #
-# $Id: portfolio.pm,v 1.186 2007/07/10 20:51:46 albertel Exp $
+# $Id: portfolio.pm,v 1.190 2008/02/05 05:54:59 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -99,7 +99,7 @@ sub display_common {
 	my $help_createdir = &Apache::loncommon::help_open_topic('Portfolio CreateDirectory');
 		
 	# FIXME: This line should be deleted once Portfolio uses breadcrumbs
-	$r->print(&Apache::loncommon::help_open_topic('Portfolio About', 'Help on the portfolio'));
+	$r->print(&Apache::loncommon::help_open_topic('Portfolio About', &mt('Help on the portfolio')));
 
         $r->print(<<"TABLE"); 
 <table id="LC_portfolio_actions">
@@ -267,15 +267,16 @@ sub display_directory {
     } else {
         $r->print('<form method="post" action="'.$url.'">');
 	$r->print(&Apache::loncommon::help_open_topic('Portfolio FileList',
-						      'Using the portfolio file list'));
+						      &mt('Using the portfolio file list')));
         $r->print('<table id="LC_browser">'.
-		  '<tr><th colspan="2">Actions'.
-		  &Apache::loncommon::help_open_topic('Portfolio FileAction').
-		  '</th><th>&nbsp;</th><th>&nbsp;</th><th>Name'.
-		  &Apache::loncommon::help_open_topic('Portfolio OpenFile').
-		  '</th><th>Size</th><th>Last Modified</th><th>Current Access Status'.
-		  &Apache::loncommon::help_open_topic('Portfolio ShareFile').
-		  '</th></tr>');
+                  '<tr>'
+                 .'<th colspan="2">'.&mt('Actions'). &Apache::loncommon::help_open_topic('Portfolio FileAction').'</th>'
+                 .'<th>&nbsp;</th><th>&nbsp;</th>'
+                 .'<th>'.&mt('Name').&Apache::loncommon::help_open_topic('Portfolio OpenFile').'</th>'
+                 .'<th>'.&mt('Size').'</th>'
+                 .'<th>'.&mt('Last Modified').'</th>'
+                 .'<th>'.&mt('Current Access Status').&Apache::loncommon::help_open_topic('Portfolio ShareFile').'</th>'
+                 .'</tr>');
     }
     $r->print("\n".&group_form_data()."\n");
 
@@ -338,7 +339,7 @@ sub display_directory {
 		    undef($colspan);
                 }
 		$r->print('<tr class="LC_browser_folder"><td '.$colspan.'><img alt="'.&mt('closed folder').'" src="'.$iconpath.'folder_closed.gif" /></td>');
-                $r->print('<td>Go to ...</td>');
+                $r->print('<td>'.&mt('Go to ...').'</td>');
                 my %anchor_fields = (
                     'selectfile'    => $filename.'/',
                     'currentpath'   => $current_path.$filename.'/',
@@ -362,7 +363,7 @@ sub display_directory {
                         my %anchor_fields = (
                             'lockinfo' => $fullpath
                         );
-                        $line.='<td colspan="2">'.&make_anchor($url,\%anchor_fields,'Locked').'</td>';
+                        $line.='<td colspan="2">'.&make_anchor($url,\%anchor_fields,&mt('Locked')).'</td>';
 			$css_class= 'LC_browser_file_locked';
                     } else {
                         if (!$can_modify) {
@@ -380,7 +381,7 @@ sub display_directory {
                                 'rename' => $filename,
                                 currentpath => $current_path
                             );
-                            $line .= &make_anchor($url,\%anchor_fields,'Rename');
+                            $line .= &make_anchor($url,\%anchor_fields,&mt('Rename'));
                             $line .= '</td><td>'.&make_anchor($href_edit_location.$filename.'.meta',\%anchor_fields,$cat);
                             # '<a href="'.$href_edit_location.$filename.'.meta">'.$cat.'</a>';
                         }
@@ -449,7 +450,7 @@ sub display_directory {
         $r->print('</table>');
         if ($can_delete) {
             $r->print('
-        <input type="submit" name="doit" value="Delete Checked Files" />'.
+        <input type="submit" name="doit" value="'.&mt('Delete Checked Files').'" />'.
 	&Apache::loncommon::help_open_topic('Portfolio DeleteFile').'
         <input type="hidden" name="action" value="delete" />
         <input type="hidden" name="currentpath" value="'.$current_path.'" />
@@ -537,12 +538,12 @@ sub delete {
     my @files=&Apache::loncommon::get_env_multiple('form.selectfile');
     my ($uname,$udom) = &get_name_dom();
     if (&Apache::lonnet::is_locked($file_name,$udom,$uname) eq 'true') {
-        $r->print("The file is locked and cannot be deleted.<br />");
+        $r->print(&mt('The file is locked and cannot be deleted.').'<br />');
         $r->print(&done('Back',$url));
     } else {
         if (scalar(@files)) {
             &open_form($r,$url);
-            $r->print('<p>'.&mt('Delete').' '.&display_file(undef,\@files).'?</p>');
+            $r->print('<p>'.&mt('Delete [_1]?',&display_file(undef,\@files)).'</p>');
             &close_form($r,$url);
         } else {
             $r->print("No file was checked to delete.<br />");
@@ -564,10 +565,10 @@ sub delete_confirmed {
 					       $env{'form.currentpath'}.
 					       $delete_file);
         if ($result ne 'ok') {
-	    $r->print('<span class="LC_error">'.
-                     &mt('An error occurred ([_1]) while trying to delete 
-                         [_2].',$result,&display_file(undef, $delete_file)).
-                      '</span><br /><br />');
+	    $r->print('<span class="LC_error">'
+                      .&mt('An error occurred ([_1]) while trying to delete [_2].'
+                         ,$result,&display_file(undef, $delete_file))
+                      .'</span><br /><br />');
         } else {
             $r->print(&mt('File: [_1] deleted.',
                           &display_file(undef,$delete_file)));
@@ -609,7 +610,7 @@ sub delete_confirmed {
 sub delete_dir {
     my ($r,$url)=@_;
     &open_form($r,$url);
-    $r->print('<p>'.&mt('Delete').' '.&display_file().'?</p>');
+     $r->print('<p>'.&mt('Delete [_1]?',&display_file()).'</p>');
     &close_form($r,$url);
 } 
 
@@ -624,8 +625,10 @@ sub delete_dir_confirmed {
 					       $directory_name);
 					       
     if ($result ne 'ok') {
-	$r->print('<span class="LC_error"> An error occurred (dir) ('.$result.
-		  ') while trying to delete '.$directory_name.'</span><br />');
+	$r->print('<span class="LC_error">'
+                  .&mt('An error occurred (dir) ([_1]) while trying to delete [_2].'
+                       ,$result,$directory_name)
+                  .'</span><br />');
     } else {
         # now remove from recent
         &Apache::lonhtmlcommon::remove_recent($namespace,[$directory_name.'/']);
@@ -649,8 +652,8 @@ sub rename {
         $r->print(&done(undef,$url));
     } else {
         &open_form($r,$url);
-        $r->print('<p>'.&mt('Rename').' '.&display_file().' to 
-                   <input name="filenewname" type="input" size="50" />?</p>');
+        $r->print('<p>'.&mt('Rename [_1] to [_2]?', &display_file()
+                  , '<input name="filenewname" type="input" size="50" />').'</p>');
         &close_form($r,$url);
     }
 }
@@ -676,9 +679,9 @@ sub rename_confirmed {
         $chg_access = &access_for_renamed($filenewname,$group,$udom,$uname);
     } else {      
 	$r->print('<span class="LC_error">'.
-		  &mt('An error occurred ([_1]) while trying to rename [_2]'
-		      .' to [_3]',$result,&display_file(),
-		      &display_file('',$filenewname)).'</span><br />');
+		  &mt('An error occurred ([_1]) while trying to rename [_2] to [_3].'
+                      ,$result,&display_file(),&display_file('',$filenewname))
+                  .'</span><br />');
         return;
     }
     if ($filenewname ne $env{'form.filenewname'}) {
@@ -774,14 +777,14 @@ sub display_access {
     if ($can_setacl) {
         &open_form($r,$url);
         $r->print($header.$info);
-	$r->print('<br />'.&Apache::loncommon::help_open_topic('Portfolio ShareFile SetAccess', 'Help on setting up share access'));
-	$r->print(&Apache::loncommon::help_open_topic('Portfolio ShareFile ChangeSetting', 'Help on changing settings'));
-	$r->print(&Apache::loncommon::help_open_topic('Portfolio ShareFile StopAccess', 'Help on removing share access'));
+	$r->print('<br />'.&Apache::loncommon::help_open_topic('Portfolio ShareFile SetAccess', &mt('Help on setting up share access')));
+	$r->print(&Apache::loncommon::help_open_topic('Portfolio ShareFile ChangeSetting', &mt('Help on changing settings')));
+	$r->print(&Apache::loncommon::help_open_topic('Portfolio ShareFile StopAccess', &mt('Help on removing share access')));
         &access_setting_table($r,$url,$file_name,$access_controls{$file_name},
                               $action);
         my $button_text = {
                         'continue' => &mt('Proceed'),
-                        'cancel' => &mt('Back to directory listing'),
+                        'cancel' => &mt('Return to directory'),
                       };
         &close_form($r,$url,$button_text);
     } else {
@@ -809,7 +812,7 @@ sub view_access_settings {
         $todisplay{$scope}{$key} = $$access_controls{$key};
     }
     if ($aclcount) {
-        $r->print(&mt('<h4>Current access controls defined for this file:</h4>'));
+        $r->print('<h4>'.&mt('Current access controls defined for this file:').'</h4>');
         $r->print(&Apache::loncommon::start_data_table());
         $r->print(&Apache::loncommon::start_data_table_header_row());
         $r->print('<th>'.&mt('Access control').'</th><th>'.&mt('Dates available').
@@ -820,12 +823,12 @@ sub view_access_settings {
         &build_access_summary($r,$count,$chg,%todisplay);
         $r->print(&Apache::loncommon::end_data_table());
     } else {
-        $r->print(&mt('No access control settings currently exist for this file.<br />' ));
+        $r->print(&mt('No access control settings currently exist for this file.').'<br />');
     }
     my %anchor_fields = (
         'currentpath' => $env{'form.currentpath'}
     );
-    $r->print('<br />'.&make_anchor($url, \%anchor_fields, &mt('Return to directory listing')));
+    $r->print('<br />'.&make_anchor($url, \%anchor_fields, &mt('Return to directory')));
     return;
 }
 
@@ -1030,7 +1033,7 @@ sub update_access {
         &open_form($r,$url);
         foreach my $newitem ('course','domains','users') {
             if ($env{'form.new'.$newitem} > 0) {
-                $r->print('<br />'.&mt('Add new <b>[_1]-based</b> access control for portfolio file: <b>[_2]</b>',$newitem,$env{'form.currentpath'}.$env{'form.selectfile'}).'<br /><br />');
+                $r->print('<br />'.&mt('Add new <b>[_1]-based</b> access control for portfolio file: <b>[_2]</b>',&mt($newitem),$env{'form.currentpath'}.$env{'form.selectfile'}).'<br /><br />');
                 $firstitem = $totalnew;
                 $lastitem = $totalnew + $env{'form.new'.$newitem};
                 $totalnew = $lastitem;
@@ -1050,7 +1053,7 @@ sub update_access {
         );
         $r->print('<br />'.&make_anchor($url, \%anchor_fields, &mt('Display all access settings for this file')));
         delete $anchor_fields{'access'};
-        $r->print('&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;'.&make_anchor($url,\%anchor_fields,&mt('Return to directory listing')));
+        $r->print('&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;'.&make_anchor($url,\%anchor_fields,&mt('Return to directory')));
     }
     return;
 }
@@ -1198,7 +1201,7 @@ sub access_setting_table {
 sub standard_settings {
     my ($r,$now,$then,$url,$filename,$acl_count,$start,$end,$public,$publicnum,
       $publictext,$guest,$guestnum,$guesttext,$access_controls,%conditionals)=@_;
-    $r->print('<h3>'.&mt('Public access: [_1]',$publictext).'</h3>');
+    $r->print('<h3>'.&mt('Public access: [_1]',&mt($publictext)).'</h3>');
     $r->print(&Apache::loncommon::start_data_table());
     $r->print(&Apache::loncommon::start_data_table_header_row());
     $r->print('<th>'.&mt('Action').'</th><th>'.&mt('Dates available').'</th>');
@@ -1214,7 +1217,7 @@ sub standard_settings {
     $r->print(&Apache::loncommon::end_data_table_row());
     $r->print(&Apache::loncommon::end_data_table());
     $r->print('</td><td width="40">&nbsp;</td><td valign="top">');
-    $r->print('<h3>'.&mt('Passphrase-protected access: [_1]',$guesttext).'</h3>');
+    $r->print('<h3>'.&mt('Passphrase-protected access: [_1]',&mt($guesttext)).'</h3>');
     $r->print(&Apache::loncommon::start_data_table());
     $r->print(&Apache::loncommon::start_data_table_header_row());
     $r->print('<th>'.&mt('Action').'</th><th>'.&mt('Dates available').
@@ -1260,7 +1263,7 @@ sub standard_settings {
             'action' => 'chgconditions',
             'currentpath' => $env{'form.currentpath'},
         );
-    $r->print('<h3>'.&mt('Conditional access: [_1]',$conditionstext).'</h3>');
+    $r->print('<h3>'.&mt('Conditional access: [_1]',&mt($conditionstext)).'</h3>');
     if ($numconditionals > 0) {
         my $count = 1;
         my $chg = 'none';
@@ -1310,7 +1313,7 @@ sub access_element {
     my $title = $type;
     $title =~ s/s$//;
     $title =~ s/^(\w)/uc($1)/e;
-    $r->print('<h3>'.&mt('[_1]-based conditional access: ',$title));
+    $r->print('<h3>'.&mt('[_1]-based conditional access: ',&mt($title)));
     if ($$acl_count{$type}) {
         $r->print($$acl_count{$type}.' ');
         if ($$acl_count{$type} > 1) {
@@ -1365,8 +1368,8 @@ sub display_access_row {
         }
         $r->print(&Apache::loncommon::end_data_table());
     } else {
-        $r->print(&mt('No [_1]-based conditions defined.<br />',$type).
-                  &additional_item($type));
+        $r->print(&mt('No [_1]-based conditions defined.',&mt($type)).'<br />'
+                  .&additional_item($type));
     }
     return;
 }
@@ -1525,7 +1528,7 @@ sub users_row {
 
 sub additional_item {
     my ($type) = @_;
-    my $output = &mt('Add new [_1] condition(s)?',$type).'&nbsp;'.&mt('Number to add: ').'<input type="text" name="new'.$type.'" size="3" value="0" />';
+    my $output = &mt('Add new [_1] condition(s)?',&mt($type)).'&nbsp;'.&mt('Number to add: ').'<input type="text" name="new'.$type.'" size="3" value="0" />';
     return $output;
 }
 
@@ -1780,7 +1783,7 @@ sub check_for_upload {
     } elsif ($found_file) {
         if ($locked_file) {
             my $msg = '<span class="LC_error">';
-            $msg .= &mt('Unable to upload [_1] a locked file by that name was found in [_2].','<span class="LC_filename">'.$fname.'</span>','<span class="LC_filename">'.$port_path.$env{'form.currentpath'}.'</span>');
+            $msg .= &mt('Unable to upload [_1]. A locked file by that name was found in [_2].','<span class="LC_filename">'.$fname.'</span>','<span class="LC_filename">'.$port_path.$env{'form.currentpath'}.'</span>');
             $msg .= '</span><br />';
             $msg .= &mt('You will be able to rename or delete existing [_1] after a grade has been assigned.','<span class="LC_filename">'.$fname.'</span>');
 	    return ('file_locked',$msg);
@@ -1820,8 +1823,8 @@ sub upload {
 					$port_path.$env{'form.currentpath'},
 					$mode,\%allfiles,\%codebase);
     if ($result !~ m|^/uploaded/|) {
-	$r->print('<span class="LC_error">'.'An error occurred ('.$result.
-		  ') while trying to upload '.&display_file().'</span><br />');
+	$r->print('<span class="LC_error">'.&mt('An error occurred ([_1]) while trying to upload [_2].'
+                  ,$result,&display_file()).'</span><br />');
 	$r->print(&done('Back',$url));
     } else {
 	if (%allfiles) {
@@ -1837,7 +1840,7 @@ STATE
 	    $r->print(&Apache::londocs::ask_for_embedded_content('/adm/portfolio',$state,\%allfiles,\%codebase,
 				      {'error_on_invalid_names'   => 1,
 				       'ignore_remote_references' => 1,}));
-	    $r->print('<p>Or '.&done('Return to directory listing',$url).'</p>');
+	    $r->print('<p>Or '.&done('Return to directory',$url).'</p>');
 	} else {
 	    $r->print(&done(undef,$url));
 	}
@@ -1879,8 +1882,10 @@ sub upload_embedded {
 	    &Apache::lonnet::userfileupload('embedded_item_'.$i,'',
 					    $port_path.$path);
 	if ($result !~ m|^/uploaded/|) {
-	    $r->print('<span class="LC_error">'.'An error occurred ('.$result.
-		      ') while trying to upload '.$orig_uploaded_filename.' for embedded element '.$env{'form.embedded_orig_'.$i}.'</span><br />');
+	    $r->print('<span class="LC_error">'
+                      .&mt('An error occurred ([_1]) while trying to upload [_2] for embedded element [_3].'
+                           ,$result,$orig_uploaded_filename,$env{'form.embedded_orig_'.$i})
+                      .'</span><br />');
 	    next;
 	} else {
 	    $r->print("<p> Uploaded ".
@@ -1925,8 +1930,7 @@ sub lock_info {
 	    my %course_description = 
 		&Apache::lonnet::coursedescription($$array_item[1]);
 	    if ( $course_description{'description'} ne '') {
-		$r->print(&mt('In the course: <strong>[_1]</strong><br />',
-			      $course_description{'description'}));
+		$r->print(&mt('In the course:').' <strong>'.$course_description{'description'}.'</strong><br />');
 	    }
         }
     }
@@ -1954,20 +1958,24 @@ sub createdir {
         }
     }
     if ($found_file){
-    	    $r->print('<span class="LC_error">'.&mt('Unable to create a directory named').' <strong>'.$newdir.
-    	            ' </strong>'.&mt('a file or directory by that name already exists.').'</span><br />');
+    	    $r->print('<span class="LC_error">'
+                      .&mt('Unable to create a directory named [_1].','<strong>'.$newdir.'</strong>')
+                      .' '.&mt('A file or directory by that name already exists.').'</span><br />');
     } else {
         my ($uname,$udom) = &get_name_dom();
         my $port_path = &get_port_path();
         my $result=&Apache::lonnet::mkdiruserfile($uname,$udom,
 	         $port_path.$env{'form.currentpath'}.$newdir);
         if ($result ne 'ok') {
-    	    $r->print('<span class="LC_error">'.'An error occurred ('.$result.
-	    	      ') while trying to create a new directory '.&display_file().'</span><br />');
+    	    $r->print('<span class="LC_error">'
+                      .&mt('An error occurred ([_1]) while trying to create a new directory [_2].'
+                           ,$result,&display_file())
+                      .'</span><br />');
         }
     }
     if ($newdir ne $env{'form.newdir'}) {
-        $r->print(&mt("The new directory name was changed from:<br /><strong>").$env{'form.newdir'}."</strong> ".&mt('to')." <strong>$newdir </strong>");  
+        $r->print(&mt('The new directory name was changed from [_1] to [_2].'
+                      ,'<strong>'.$env{'form.newdir'}.'</strong>','<strong>'.$newdir.'</strong>'));  
     }
     $r->print(&done(undef,$url));
 }
@@ -2068,7 +2076,7 @@ sub missing_priv {
         $rtnlink .= '?';
     }
     $rtnlink .= 'currentpath='.$escpath;
-    $r->print(&mt('<h3>Action disallowed</h3>'));
+    $r->print('<h3>'.&mt('Action disallowed').'</h3>');
     $r->print(&mt('You do not have sufficient privileges to [_1] ',
                   $longtext->{$priv}));
     if (defined($env{'form.group'})) {
@@ -2077,7 +2085,7 @@ sub missing_priv {
     } else {
         $r->print(&mt('in this portfolio.'));
     }
-    $rtnlink .= '">'.&mt('Return to directory listing page').'</a>';
+    $rtnlink .= '">'.&mt('Return to directory').'</a>';
     $r->print('<br />'.$rtnlink);
     $r->print(&Apache::loncommon::end_page());
     return;
@@ -2169,7 +2177,7 @@ sub handler {
                 $r->print(&mt('Not a valid group for this course'));
                 $earlyout = 1;
             }
-            $title = &mt('Group files').' for '.$group; 
+            $title = &mt('Group files for [_1]', $group); 
         } else {
             $r->print(&mt('Invalid group'));
             $earlyout = 1;
@@ -2228,8 +2236,8 @@ sub handler {
     }
 	if (($env{'form.storeupl'}) & (!$env{'form.uploaddoc.filename'})){
    	    $r->print('<span class="LC_error">');
-   	    $r->print(&mt('No file was selected to upload. '));
-	    $r->print(&mt('To upload a file, click <strong>Browse...</strong> select a file, then click <strong>Upload</strong>.'));
+   	    $r->print(&mt('No file was selected to upload.').' ');
+	    $r->print(&mt('To upload a file, click <strong>Browse...</strong> and select a file, then click <strong>Upload</strong>.'));
 	    $r->print('</span>');
 	}
     if ($env{'form.meta'}) {
