@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.42 2007/10/18 21:08:31 albertel Exp $
+# $Id: lonlocal.pm,v 1.43 2008/01/29 13:26:09 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -289,7 +289,8 @@ sub locallocaltime {
 	my $day        = $dt->day_of_month();
 	my $mon        = $dt->month()-1;
 	my $year       = $dt->year();
-	my $wday       = $dt->wday()-1;
+	my $wday       = $dt->wday();
+        if ($wday==7) { $wday=0; }
 	my $month  =(split(/\,/,$lh->maketext('date_months')))[$mon];
 	my $weekday=(split(/\,/,$lh->maketext('date_days')))[$wday];
 	if ($seconds<10) {
