@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonmetadata.pm,v 1.24 2007/08/18 00:32:05 albertel Exp $
+# $Id: lonmetadata.pm,v 1.25 2007/12/07 22:31:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1183,8 +1183,8 @@ sub process_allusers_data {
         if ($udom eq '' || $uname eq '' ) {
             $error = 'No domain and/or username specified';
         } else {
-            $delitem = 'domain = '.$dbh->quote($udom).' AND username = '.
-                       $dbh->quote($uname);
+            $delitem = 'domain = '.$dbh->quote($udom).' AND username '.
+                       'COLLATE latin1_general_cs = '.$dbh->quote($uname);
             $error=&delete_metadata($dbh,$newnames->{'allusers'},$delitem);
         }
         if (defined($error)) {
