@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.229 2007/09/24 13:59:09 www Exp $
+# $Id: lonpublisher.pm,v 1.232 2008/03/18 23:31:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -344,8 +344,8 @@ sub text_with_browse_field {
     return "\n<p><font color=\"#800000\" face=\"helvetica\"><b>$title:".
            "</b></font></p><br />".
            '<input type="text" name="'.$name.'" size=80 value="'.$value.'" />'.
-	   '<a href="javascript:openbrowser(\'pubform\',\''.$name.'\',\''.$restriction.'\');">Select</a>&nbsp;'.
-	   '<a href="javascript:opensearcher(\'pubform\',\''.$name.'\');">Search</a>';
+	   '<a href="javascript:openbrowser(\'pubform\',\''.$name.'\',\''.$restriction.'\');">'.&mt('Select').'</a>&nbsp;'.
+	   '<a href="javascript:opensearcher(\'pubform\',\''.$name.'\');">'.&mt('Search').'</a>';
 	   
 }
 
@@ -964,18 +964,23 @@ sub publish {
     
 	$scrout.='<h3>'.&mt('Dependencies').'</h3>';
         my $allowstr='';
-        foreach (sort(keys(%allow))) {
-	   my $thisdep=$_;
+        foreach my $thisdep (sort(keys(%allow))) {
 	   if ($thisdep !~ /[^\s]/) { next; }
+           if ($thisdep =~/\$/) {
+              $scrout.='<br /><span class="LC_warning">'
+                       .&mt('The resource depends on another resource with variable filename, i.e., [_1].','<tt>'.$thisdep.'</tt>').'<br />'
+                       .&mt('You likely need to explicitly allow access to all possible dependencies using the [_1]-tag.','<tt>&lt;allow&gt;</tt>')
+                       .'</span><br />';
+           }
            unless ($style eq 'rat') { 
               $allowstr.="\n".'<allow src="'.$thisdep.'" />';
 	   }
            $scrout.='<br />';
-           if ($thisdep!~/\*/ && $thisdep!~m|^/adm/|) {
+           if ($thisdep!~/[\*\$]/ && $thisdep!~m|^/adm/|) {
 	       $scrout.='<a href="'.$thisdep.'">';
            }
            $scrout.='<tt>'.$thisdep.'</tt>';
-           if ($thisdep!~/\*/ && $thisdep!~m|^/adm/|) {
+           if ($thisdep!~/[\*\$]/ && $thisdep!~m|^/adm/|) {
 	       $scrout.='</a>';
                if (
        &Apache::lonnet::getfile($Apache::lonnet::perlvar{'lonDocRoot'}.'/'.
