@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.470 2007/12/05 14:52:15 albertel Exp $
+# $Id: lonxml.pm,v 1.473.2.1 2008/03/21 18:52:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -379,6 +379,10 @@ sub xmlparse {
  }
  &init_state();
  if ($env{'form.return_only_error_and_warning_counts'}) {
+     if ($env{'request.filename'}=~/\.(html|htm|xml)$/i) { 
+        my $error=&verify_html($content_file_string);
+        if ($error) { $errorcount++; }
+     }
      return "$errorcount:$warningcount";
  }
  return $finaloutput;
@@ -723,6 +727,7 @@ sub init_safespace {
   $safehole->wrap(\&Apache::chemresponse::chem_standard_order,$safeeval,
 		  '&chem_standard_order');
   $safehole->wrap(\&Apache::response::check_status,$safeeval,'&check_status');
+  $safehole->wrap(\&Apache::response::implicit_multiplication,$safeeval,'&implicit_multiplication');
 
   $safehole->wrap(\&Apache::lonmaxima::maxima_eval,$safeeval,'&maxima_eval');
   $safehole->wrap(\&Apache::lonmaxima::maxima_check,$safeeval,'&maxima_check');
@@ -1474,11 +1479,26 @@ SIMPLECONTENT
   return $filecontents;
 }
 
+sub verify_html {
+    my ($filecontents)=@_;
+    if ($filecontents!~/(?:\<|\&lt\;)(?:html|xml)[^\<]*(?:\>|\&gt\;)/is) {
+       return &mt('File does not have [_1] or [_2] starting tag','&lt;html&gt;','&lt;xml&gt;');
+    }
+    if ($filecontents!~/(?:\<|\&lt\;)\/(?:html|xml)(?:\>|\&gt\;)/is) {
+       return &mt('File does not have [_1] or [_2] ending tag','&lt;html&gt;','&lt;xml&gt;');
+    }
+    if ($filecontents!~/(?:\<|\&lt\;)(?:body|frameset)[^\<]*(?:\>|\&gt\;)/is) {
+       return &mt('File does not have [_1] or [_2] starting tag','&lt;body&gt;','&lt;frameset&gt;');
+    }
+    if ($filecontents!~/(?:\<|\&lt\;)\/(?:body|frameset)[^\<]*(?:\>|\&gt\;)/is) {
+       return &mt('File does not have [_1] or [_2] ending tag','&lt;body&gt;','&lt;frameset&gt;');
+    }
+    return '';
+}
 
 sub inserteditinfo {
       my ($filecontents, $filetype, $filename)=@_;
       $filecontents = &HTML::Entities::encode($filecontents,'<>&"');
-#      my $editheader='<a href="#editsection">Edit below</a><hr />';
       my $xml_help = '';
       my $initialize='';
       my $textarea_id = 'filecont';
@@ -1537,6 +1557,10 @@ FULLPAGE
       my $spelllink .=&Apache::lonhtmlcommon::spelllink('xmledit','filecont');
       my $textarea_events = &Apache::edit::element_change_detection();
       my $form_events     = &Apache::edit::form_change_detection();
+      my $htmlerror=&verify_html($filecontents);
+      if ($htmlerror) {
+         $htmlerror='<span class="LC_error">'.$htmlerror.'</span>';
+      }
       my $editfooter=(<<ENDFOOTER);
 $initialize
 <a name="editsection" />
@@ -1551,7 +1575,7 @@ $initialize
     <div class="LC_edit_problem_discards">
       <input type="submit" name="discardview" accesskey="d" value="$lt{'dv'}" />
       <input type="submit" name="Undo" accesskey="u" value="$lt{'un'}" />
-      $spelllink
+      $spelllink $htmlerror
     </div>
     <div class="LC_edit_problem_saves">
       <input type="submit" name="savethisfile" accesskey="s" value="$lt{'st'}" />
@@ -1628,6 +1652,9 @@ sub handler {
 	if ($env{'form.savethisfile'} || $env{'form.viewmode'} || $env{'form.Undo'}) {
 	    my $html_file=&Apache::lonnet::getfile($file);
 	    my $error = &Apache::lonhomework::handle_save_or_undo($request, \$html_file, \$env{'form.filecont'});
+            if ($env{'form.savethisfile'}) {
+                $env{'form.editmode'}='Edit'; #force edit mode
+            }
 	}
     }
     my %mystyle;
