@@ -2,6 +2,8 @@
 # Build menu bar for Advanced RAT. Uses javascript code originally in
 # static file: rat/client/code.html, now in  rat/client/ratcode.js  
 #
+# $Id: lonratmenu.pm,v 1.10 2008/03/22 01:39:05 raeburn Exp $
+#
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -41,8 +43,7 @@ sub handler {
     my %loaditem = ('onunload' => "leave();",);
     my $start_page = 
 	&Apache::loncommon::start_page('Advanced Editor',$js,
-				       {'add_entries' => \%loaditem,}).
-	&Apache::loncommon::help_open_menu('Sequence_Advanced_Editor_Creation','Sequence_Advanced_Editor_Creation',6,'RAT');
+				       {'add_entries' => \%loaditem, 'suppress_header_logos' => 1});
     $r->print($start_page);
     my $readfile=$r->uri;
     $readfile=~s/\/loadonly\/adveditmenu$//;
@@ -53,9 +54,12 @@ sub handler {
 
 sub print_html {
     my $readfile=shift;
+    my $help=&Apache::loncommon::help_open_menu('Sequence_Advanced_Editor_Creation','Sequence_Advanced_Editor_Creation',6,'RAT');
+
     my $pagetext = <<"END";
 <table border=0><tr><td bgcolor="#aaaaaa">
 <table border=0><tr>
+<td bgcolor="#ffffcc">$help</td>
 <td bgcolor="#ffffcc"><a href="javascript:togglemode();"><font size="-2">Toggle display</font></a></td>
 <td bgcolor="#ffffcc"><a href="javascript:if (zscale>1) { zscale--; draw();}"><font size="-2">Zoom out</font></a></td>
 <td bgcolor="#ffffcc"><a href="javascript:if (zscale<3) { zscale++; draw();}"><font size="-2">Zoom in</font></a></td>
